[![PyPI](https://img.shields.io/pypi/v/PolyRename)](https://pypi.org/project/PolyRename/)
[![Build Status](https://travis-ci.org/agsimmons/PolyRename.svg?branch=develop)](https://travis-ci.org/agsimmons/PolyRename)
[![Documentation Status](https://readthedocs.org/projects/polyrename/badge/?version=latest)](https://polyrename.readthedocs.io/en/latest/?badge=latest)

# PolyRename
A cross-platform, bulk-file rename tool

## Documentation
PolyRename's documentation is hosted on [ReadTheDocs](http://polyrename.readthedocs.io/)
